# MIT License
#
# Copyright (c) 2023 Clivern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import requests


class Shopify:

    def __init__(self, shop_name, access_token):
        self.shop_name = shop_name
        self.access_token = access_token
        self.base_url = f"https://{self.shop_name}.myshopify.com/admin/api/2021-07"

    def get_shop_info(self):
        url = f"{self.base_url}/shop.json"

        headers = {
            'Content-Type': 'application/json',
            'X-Shopify-Access-Token': self.access_token
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            return response.json()
        else:
            response.raise_for_status()



# MIT License
#
# Copyright (c) 2024 Clivern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import click

from pexy import __version__
from pexy.command import Info as InfoCommand


@click.group(help="🐺 Shopify Store Swiss Knife.")
@click.version_option(version=__version__, help="Show the current version")
@click.option('--name', required=True, help='Your Shopify store name (without .myshopify.com)')
@click.option('--token', required=True, help='Your Shopify access token')
def main(shop_name, token):
    """Main command group for Shopify CLI."""
    global NAME, TOKEN
    NAME = name
    TOKEN = token


@main.command(help="Get store information from Shopify")
def store_info():
    """Command to retrieve and display the store information."""
    command = InfoCommand(NAME, TOKEN)
    return command.exec()


if __name__ == "__main__":
    main()



# MIT License
#
# Copyright (c) 2023 Clivern
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import json
from re import sub
from prettytable import PrettyTable


class Output:
    """Output Class"""

    JSON = "JSON"
    DEFAULT = "DEFAULT"

    def _table(self, data):
        """Output data as Table"""
        headers = []
        rows = []

        for item in data:
            headers = item.keys()
            rows.append(item.values())

        x = PrettyTable()
        x.field_names = headers
        x.add_rows(rows)

        return x

    def _json(self, data):
        """Output data as JSON"""
        new = []

        for item in data:
            new.append({self.camel_case(k): v for k, v in item.items()})

        return json.dumps(new)

    def render(self, data, typ):
        """Render Data to the Console"""
        if typ == Output.JSON:
            return self._json(data)

        return self._table(data)

    def camel_case(self, value):
        """Change string into camel case"""
        value = sub(r"(_|-)+", " ", value).title().replace(" ", "")

        return "".join([value[0].lower(), value[1:]])
